Module cli

Module cli 

Structs

BookmarkCommand
Cli
Scan for all git folders in specified directorires, select one and open it as a new tmux session
CloneRepoCommand
ConfigArgs
ConfigCommand
ConfigSubCommandArgs
InitRepoCommand
OpenSessionCommand
RefreshCommand
RenameCommand

Enums

CliCommand
ConfigSubCommand
SubCommandGiven